Enum EvaluationResult
pub enum EvaluationResult {
EvaluatedToOk,
EvaluatedToOkModuloRegions,
EvaluatedToOkModuloOpaqueTypes,
EvaluatedToAmbig,
EvaluatedToAmbigStackDependent,
EvaluatedToErr,
}Expand description
The result of trait evaluation. The order is important here as the evaluation of a list is the maximum of the evaluations.
The evaluation results are ordered:
- EvaluatedToOk implies EvaluatedToOkModuloRegions
implies EvaluatedToAmbig implies EvaluatedToAmbigStackDependent
- the “union” of evaluation results is equal to their maximum -
all the “potential success” candidates can potentially succeed,
so they are noops when unioned with a definite error, and within
the categories it’s easy to see that the unions are correct.
Variants
EvaluatedToOk
Evaluation successful.
EvaluatedToOkModuloRegions
Evaluation successful, but there were unevaluated region obligations.
EvaluatedToOkModuloOpaqueTypes
Evaluation successful, but need to rerun because opaque types got hidden types assigned without it being known whether the opaque types are within their defining scope
EvaluatedToAmbig
Evaluation is known to be ambiguous – it might hold for some assignment of inference variables, but it might not.
While this has the same meaning as EvaluatedToAmbigStackDependent – we can’t
know whether this obligation holds or not – it is the result we
would get with an empty stack, and therefore is cacheable.
EvaluatedToAmbigStackDependent
Evaluation failed because of recursion involving inference variables. We are somewhat imprecise there, so we don’t actually know the real result.
This can’t be trivially cached because the result depends on the stack results.
EvaluatedToErr
Evaluation failed.