Enum SelectionError
pub enum SelectionError<'db> {
Unimplemented,
SignatureMismatch(Box<SignatureMismatchData<'db>>),
TraitDynIncompatible(TraitId),
NotConstEvaluatable(NotConstEvaluatable),
Overflow(OverflowError),
OpaqueTypeAutoTraitLeakageUnknown(InternedOpaqueTyId),
ConstArgHasWrongType {
ct: Const<'db>,
ct_ty: Ty<'db>,
expected_ty: Ty<'db>,
},
}Variants
Unimplemented
The trait is not implemented.
SignatureMismatch(Box<SignatureMismatchData<'db>>)
After a closure impl has selected, its “outputs” were evaluated
(which for closures includes the “input” type params) and they
didn’t resolve. See confirm_poly_trait_refs for more.
TraitDynIncompatible(TraitId)
The trait pointed by DefId is dyn-incompatible.
NotConstEvaluatable(NotConstEvaluatable)
A given constant couldn’t be evaluated.
Overflow(OverflowError)
Exceeded the recursion depth during type projection.
OpaqueTypeAutoTraitLeakageUnknown(InternedOpaqueTyId)
Computing an opaque type’s hidden type caused an error (e.g. a cycle error). We can thus not know whether the hidden type implements an auto trait, so we should not presume anything about it.
ConstArgHasWrongType
Error for a ConstArgHasType goal